pm4py.algo.discovery.inductive.variants.im package
==================================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.discovery.inductive.variants.im.data_structures
   pm4py.algo.discovery.inductive.variants.im.util

Submodules
----------

pm4py.algo.discovery.inductive.variants.im.algorithm module
-----------------------------------------------------------

.. automodule:: pm4py.algo.discovery.inductive.variants.im.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.discovery.inductive.variants.im
   :members:
   :undoc-members:
   :show-inheritance:
